@echo off
setlocal

REM We need a JVM
if not defined JAVA_HOME  (
  echo Error: JAVA_HOME is not defined.
  exit /b
)

if not exist "%JAVA_HOME%\bin\server\jvm.dll" (
  echo Error: %JAVA_HOME%\bin\server\jvm.dll not found
  exit /b
)

set IDP_HOME_WINDOWS=%~dp0..
set JETTY_BASE=%~dp0..\jetty-base
set JETTY_HOME=%~dp0..\jetty-home
set PRUNSRV=%IDP_HOME_WINDOWS%\shibd_idp\amd64\prunsrv.exe

for /f "tokens=* USEBACKQ" %%F in (`type "%JETTY_BASE%\jetty.base.linux"`) do (
    SET IDP_HOME_UNIX=%%F
)

if "%1" EQU "UNINSTALL" (
    @echo on
    %PRUNSRV% //DS/Shibd_idp
    exit /b
)

if "%1" EQU "EDIT" (
    @echo on
    start %IDP_HOME_WINDOWS%\shibd_idp\prunmgr //ES/Shibd_idp
    exit /b
)

if NOT "%1" EQU "INSTALL" (
   echo "Usage : XXXX [INSTALL|UNINSTALL] [User]
   exit /b
)

if NOT "%2" EQU "" (
   USERNAME=%2
   SET /P PASSWORD="Password for %USERNAME%: "
   SET PR_SERVICEUSER=%USERNAME%
   SET PR_SERVICEPASSWORD=%PASSWORD%
) else (
    SET USERNAME=LocalService
)


REM
REM First up create and configure the procrun instance which will run jetty
REM This is described in
REM https://commons.apache.org/proper/commons-daemon/procrun.html
REM And what is set comes from the jetty documentation
REM
SET PORTPASS=%random%-%random%-%random%-%random%

REM
REM Use PR_xxx for parameters to keep things legible and to allow for spaces in paths
REM
SET PR_DISPLAYNAME=Shibboleth IdP Daemon
SET PR_DESCRIPTION=Runs the Jetty Container
SET PR_CLASSPATH=%JETTY_HOME%\start.jar
SET PR_JVMOPTIONS=-Didp.home=%IDP_HOME_UNIX%;-Djdk.tls.ephemeralDHKeySize=2048;-Dorg.eclipse.jetty.util.log.class=org.eclipse.jetty.util.log.Slf4jLog;-Djava.io.tmpdir=%JETTY_BASE%\tmp;-XX:+UseG1GC
SET PR_JVMMX=2048
SET PR_JVM=auto
SET PR_JAVAHOME=%JAVA_HOME%

SET PR_LOGPATH=%IDP_HOME_WINDOWS%\logs
SET PR_STDOUTPUT=auto
SET PR_STDERROR=auto

SET PR_STARTMODE=JVM
SET PR_STARTCLASS=org.eclipse.jetty.start.Main
SET PR_STARTPARAMS=STOP_PORT=8963;STOP.KEY=%PORTPASS%;jetty.base=%JETTY_BASE%;jetty.logging.dir=%IDP_HOME_WINDOWS%\logs

SET PR_STOPMODE=JVM
SET PR_STOPCLASS=org.eclipse.jetty.start.Main
SET PR_STOPPARAMS=--stop;%PR_STARTPARAMS%

%PRUNSRV% //IS/Shibd_idp --Startup=auto

REM
REM With that done poke holes in the firewall using "netsh advfirewall"
REM
REM netsh advfirewall firewall add rule name="Shibboleth IdP Service" dir=in action=allow program="%PRUNSRV% " enable=yes protocol=tcp

REM
REM Lock down the install
REM
call %~dp0\setacl.bat %USERNAME%

REM
REM We also need to lock down jetty-base-tmp
REM
echo Setting FULL ACL on %JETTY_BASE%\tmp directory for SYSTEM,  Administrators and %USERNAME%
icacls "%JETTY_BASE%\tmp" /t /inheritance:r /grant:r "SYSTEM:(OI)(CI)(F)" "Administrators:(OI)(CI)(F)" "%USERNAME%:(OI)(CI)(F)" /q
if ERRORLEVEL 1 (
   echo Error: Could not set ACL
   exit /b
)

echo Setting FULL ACL on %JETTY_BASE%\tmp directory content for SYSTEM,  Administrators and %USERNAME%
icacls "%JETTY_BASE%\tmp" /t /inheritance:r /grant:r SYSTEM:F Administrators:F "%USERNAME%:F" /q
if ERRORLEVEL 1 (
  echo Error: Could not set ACL
  exit /b
)


REM
REM start the service
REM

%PRUNSRV% //ES/Shibd_idp

REM
REM All done!
REM
exit /b


